# What is this package?
This package (weather-usa) is a wrapper for portions of the IEM and NWS APIs.
It uses asyncio for when calling multiple requests to speed up the time it takes to access said data when needed.

# How do I install this?
`pip install weather-usa`

# Where is the documentation?
It will be coming soon after a few changes.
